
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2014 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_EXPORTDEVICEDIALOG_H
#define RG_EXPORTDEVICEDIALOG_H

#include <QDialog>
#include <QString>


class QWidget;
class QRadioButton;


namespace Rosegarden
{



class ExportDeviceDialog : public QDialog
{
    //Q_OBJECT
public:
    enum ExportType { ExportOne, ExportAll };
    
    ExportDeviceDialog(QWidget *parent, QString deviceName);
    
    ExportType getExportType();

protected:
    QRadioButton *m_exportAll;
    QRadioButton *m_exportOne;
};



}

#endif
